////////////////////////////////////////////////////////////////////////////////
///
///		Title		: KeyEvent File
///
///		Copyright (c) 2006, NHN Co., Ltd. ALL RIGHTS RESERVED
///
///		Team		: Desktop Service Development
///
////////////////////////////////////////////////////////////////////////////////
#pragma once

#include "BaseEvent.h"
class CComponent;
/**
* @ingroup 	Base UI	
* @brief 	KeyEvent class
* @date		10/23/2006
* @author	telltale
* @remark	
*/
class CKeyEvent
{
public:
	CKeyEvent(CComponent* pComponent, UINT nChar, UINT nRepCount, UINT nFlags)
	{
		m_pEventSource = pComponent;
		m_nChar = nChar;
		m_nRepCount = nRepCount;
		m_nFlags = nFlags;
	}
	virtual ~CKeyEvent()
	{

	}
	///< event source
	CComponent* m_pEventSource;
	///< specifies the virtual key code of the given key
	UINT m_nChar;
	///< specifies the repeat count
	UINT m_nRepCount;
	///< specifies the scan code, key-transition code, previous key state, and context code
	UINT m_nFlags;
};
/**
* @ingroup 	Base UI	
* @brief 	KeyListener class
* @date		10/23/2006
* @author	telltale
* @remark	
*/
interface	IKeyListener : public IBaseListener
{
public:
	virtual ~IKeyListener() {  }
	/**
	* @brief 	whenever the key is pressed in focused component
	* @param	nChar	specifies the virtual key code of the given key
	* @param	nRepCount	specifies the repeat count
	* @param	nFlags	specifies the scan code, key-transition code, previous key state, and context code
	* @return	none
	*/
	virtual void	OnKeyPressed(CKeyEvent* pKeyEvent) = 0;
	/**
	* @brief 	whenever the key is released in focused component
	* @param	nChar	specifies the virtual key code of the given key
	* @param	nRepCount	specifies the repeat count
	* @param	nFlags	specifies the scan code, key-transition code, previous key state, and context code
	* @return	none
	*/
	virtual void	OnKeyReleased(CKeyEvent* pKeyEvent) = 0;
};